==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/KafkaMirrorMaker2TemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface KafkaMirrorMaker2TemplateFluent<A extends KafkaMirrorMaker2TemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public DeploymentTemplate getDeployment();
    public DeploymentTemplate buildDeployment();
    public A withDeployment(DeploymentTemplate deployment);
    public Boolean hasDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> withNewDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> withNewDeploymentLike(DeploymentTemplate item);
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> editDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(DeploymentTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> withNewPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> editPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> editOrNewPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildApiService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getApiService();
    public ResourceTemplate buildApiService();
    public A withApiService(ResourceTemplate apiService);
    public Boolean hasApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> withNewApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> withNewApiServiceLike(ResourceTemplate item);
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> editApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> editOrNewApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> editOrNewApiServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildMirrorMaker2Container instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getMirrorMaker2Container();
    public ContainerTemplate buildMirrorMaker2Container();
    public A withMirrorMaker2Container(ContainerTemplate mirrorMaker2Container);
    public Boolean hasMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> withNewMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> withNewMirrorMaker2ContainerLike(ContainerTemplate item);
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> editMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> editOrNewMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> editOrNewMirrorMaker2ContainerLike(ContainerTemplate item);

    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentTemplateFluent<KafkaMirrorMaker2TemplateFluent.DeploymentNested<N>>{

        
    public N and();    public N endDeployment();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<KafkaMirrorMaker2TemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface ApiServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<KafkaMirrorMaker2TemplateFluent.ApiServiceNested<N>>{

        
    public N and();    public N endApiService();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface MirrorMaker2ContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<N>>{

        
    public N and();    public N endMirrorMaker2Container();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/template/KafkaMirrorMaker2TemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface KafkaMirrorMaker2TemplateFluent<A extends KafkaMirrorMaker2TemplateFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public DeploymentTemplate getDeployment();
    public DeploymentTemplate buildDeployment();
    public A withDeployment(DeploymentTemplate deployment);
    public Boolean hasDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> withNewDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> withNewDeploymentLike(DeploymentTemplate item);
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> editDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public KafkaMirrorMaker2TemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(DeploymentTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> withNewPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> editPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> editOrNewPod();
    public KafkaMirrorMaker2TemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildApiService instead.
 * @return The buildable object.
 */
@Deprecated public InternalServiceTemplate getApiService();
    public InternalServiceTemplate buildApiService();
    public A withApiService(InternalServiceTemplate apiService);
    public Boolean hasApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> withNewApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> withNewApiServiceLike(InternalServiceTemplate item);
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> editApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> editOrNewApiService();
    public KafkaMirrorMaker2TemplateFluent.ApiServiceNested<A> editOrNewApiServiceLike(InternalServiceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildMirrorMaker2Container instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getMirrorMaker2Container();
    public ContainerTemplate buildMirrorMaker2Container();
    public A withMirrorMaker2Container(ContainerTemplate mirrorMaker2Container);
    public Boolean hasMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> withNewMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> withNewMirrorMaker2ContainerLike(ContainerTemplate item);
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> editMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> editOrNewMirrorMaker2Container();
    public KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<A> editOrNewMirrorMaker2ContainerLike(ContainerTemplate item);
    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentTemplateFluent<KafkaMirrorMaker2TemplateFluent.DeploymentNested<N>> {

            public N and();
            public N endDeployment();    }


    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<KafkaMirrorMaker2TemplateFluent.PodNested<N>> {

            public N and();
            public N endPod();    }


    public interface ApiServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InternalServiceTemplateFluent<KafkaMirrorMaker2TemplateFluent.ApiServiceNested<N>> {

            public N and();
            public N endApiService();    }


    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<KafkaMirrorMaker2TemplateFluent.PodDisruptionBudgetNested<N>> {

            public N and();
            public N endPodDisruptionBudget();    }


    public interface MirrorMaker2ContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<KafkaMirrorMaker2TemplateFluent.MirrorMaker2ContainerNested<N>> {

            public N and();
            public N endMirrorMaker2Container();    }


}
